==> kubernetes-model-apps-6.2.0-sources.jar: io/fabric8/kubernetes/api/model/apps/RollingUpdateStatefulSetStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.model.IntOrString;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RollingUpdateStatefulSetStrategyFluentImpl<A extends RollingUpdateStatefulSetStrategyFluent<A>> extends BaseFluent<A> implements RollingUpdateStatefulSetStrategyFluent<A>{
  public RollingUpdateStatefulSetStrategyFluentImpl() {
  }
  public RollingUpdateStatefulSetStrategyFluentImpl(RollingUpdateStatefulSetStrategy instance) {
    this.withMaxUnavailable(instance.getMaxUnavailable()); 
    this.withPartition(instance.getPartition()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private IntOrStringBuilder maxUnavailable;
  private Integer partition;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} else { this.maxUnavailable = null; _visitables.get("maxUnavailable").remove(this.maxUnavailable); } return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(Object value) {
    return (A)withMaxUnavailable(new IntOrString(value));
  }
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNestedImpl();
  }
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item) {
    return new RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new IntOrStringBuilder().build());
  }
  public RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  public Integer getPartition() {
    return this.partition;
  }
  public A withPartition(Integer partition) {
    this.partition=partition; return (A) this;
  }
  public Boolean hasPartition() {
    return this.partition != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    RollingUpdateStatefulSetStrategyFluentImpl that = (RollingUpdateStatefulSetStrategyFluentImpl) o;
    if (maxUnavailable != null ? !maxUnavailable.equals(that.maxUnavailable) :that.maxUnavailable != null) return false;
    if (partition != null ? !partition.equals(that.partition) :that.partition != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  partition,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (partition != null) { sb.append("partition:"); sb.append(partition + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MaxUnavailableNestedImpl<N> extends IntOrStringFluentImpl<RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<N>> implements RollingUpdateStatefulSetStrategyFluent.MaxUnavailableNested<N>,Nested<N>{
    MaxUnavailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateStatefulSetStrategyFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apps-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apps/RollingUpdateStatefulSetStrategyFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import io.fabric8.kubernetes.api.model.IntOrString;
import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.IntOrStringBuilder;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.IntOrStringFluentImpl;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class RollingUpdateStatefulSetStrategyFluentImpl<A extends RollingUpdateStatefulSetStrategyFluent<A>> extends BaseFluent<A> implements RollingUpdateStatefulSetStrategyFluent<A>{
  public RollingUpdateStatefulSetStrategyFluentImpl() {
  }
  public RollingUpdateStatefulSetStrategyFluentImpl(RollingUpdateStatefulSetStrategy instance) {
    if (instance != null) {
      this.withMaxUnavailable(instance.getMaxUnavailable());
      this.withPartition(instance.getPartition());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private IntOrStringBuilder maxUnavailable;
  private Integer partition;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildMaxUnavailable instead.
   * @return The buildable object.
   */
  @Deprecated
  public IntOrString getMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public IntOrString buildMaxUnavailable() {
    return this.maxUnavailable!=null ?this.maxUnavailable.build():null;
  }
  public A withMaxUnavailable(IntOrString maxUnavailable) {
    _visitables.get("maxUnavailable").remove(this.maxUnavailable);
    if (maxUnavailable!=null){ this.maxUnavailable= new IntOrStringBuilder(maxUnavailable); _visitables.get("maxUnavailable").add(this.maxUnavailable);} else { this.maxUnavailable = null; _visitables.get("maxUnavailable").remove(this.maxUnavailable); } return (A) this;
  }
  public Boolean hasMaxUnavailable() {
    return this.maxUnavailable != null;
  }
  public A withNewMaxUnavailable(Object value) {
    return (A)withMaxUnavailable(new IntOrString(value));
  }
  public RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<A> withNewMaxUnavailable() {
    return new RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNestedImpl();
  }
  public RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<A> withNewMaxUnavailableLike(IntOrString item) {
    return new RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNestedImpl(item);
  }
  public RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<A> editMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable());
  }
  public RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<A> editOrNewMaxUnavailable() {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): new IntOrStringBuilder().build());
  }
  public RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<A> editOrNewMaxUnavailableLike(IntOrString item) {
    return withNewMaxUnavailableLike(getMaxUnavailable() != null ? getMaxUnavailable(): item);
  }
  public Integer getPartition() {
    return this.partition;
  }
  public A withPartition(Integer partition) {
    this.partition=partition; return (A) this;
  }
  public Boolean hasPartition() {
    return this.partition != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    RollingUpdateStatefulSetStrategyFluentImpl that = (RollingUpdateStatefulSetStrategyFluentImpl) o;
    if (!java.util.Objects.equals(maxUnavailable, that.maxUnavailable)) return false;

    if (!java.util.Objects.equals(partition, that.partition)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(maxUnavailable,  partition,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (maxUnavailable != null) { sb.append("maxUnavailable:"); sb.append(maxUnavailable + ","); }
    if (partition != null) { sb.append("partition:"); sb.append(partition + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MaxUnavailableNestedImpl<N> extends IntOrStringFluentImpl<RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<N>> implements RollingUpdateStatefulSetStrategyFluentImpl.MaxUnavailableNested<N>,Nested<N>{
    MaxUnavailableNestedImpl(IntOrString item) {
      this.builder = new IntOrStringBuilder(this, item);
    }
    MaxUnavailableNestedImpl() {
      this.builder = new IntOrStringBuilder(this);
    }
    IntOrStringBuilder builder;
    public N and() {
      return (N) RollingUpdateStatefulSetStrategyFluentImpl.this.withMaxUnavailable(builder.build());
    }
    public N endMaxUnavailable() {
      return and();
    }
    
  }
  
}
